How to use these ressources ?
#############################

You're actually on the *GitHup Page* of the `Camera GUI Git Repository <https://github.com/IOGS-LEnsE-ressources/camera-gui/>`_.

This repository gathers **ressources** to setup industrial cameras (Basler, IDS...) and to collect images in **Python applications** (console or :abbr:`GUI (graphical user interface)` applications).

.. figure:: ../_static/images/pieces_machine_vision.png
	:width: 50%
	:align: center
	
	Example of machine vision image. `Machine Vision platform from the LEnsE <https://iogs-lense-platforms.github.io/machine-vision/index.html>`_

|

This repository contains :

* the **source codes** of the different wrappers in the :file:`progs/brandname/src/` directory (where brandname is the name of the camera manufacturer). 	
* **usage examples** in the :file:`progs/brandname/examples/` directory 
* the **documentation** in the :file:`docs/` directory (developed with `Sphinx <https://www.sphinx-doc.org/>`_)


GitHub repositories
*******************

There are different ways to get a copy of a repository's files on **GitHub**. To have more informations on how to download a repository, use this tutorial: `How To Use GitHub repositories <http://lense.institutoptique.fr/github/>`_ from the LEnsE.